Chart App
=========

This is a web app designed to crunch data into charts.

Demo
----

You can have a demo available at
`localhost:5001 <http://127.0.0.1:5001/>`__

.. code:: bash

    python charpy/app.py
